# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place - Suite 330, Boston, MA 02111-1307, USA, or go to
# http://www.gnu.org/copyleft/lesser.txt.
#-----------------------------------------------------------------------------
# Name        	: su2ase4id.rb
# Description 	: Export models to 3DS Max ASCII format to idTech ("Doom")
# Menu Item   	: Plugins\ASE Exporter\Export
# Author      	: Belgabor
#                Code used form following SU exporters: SU2KT by Tomasz Marek, SU2POV by Didier Bur and OGRE exporter by Kojack
# Usage     	: Copy script to PLUGINS folder in SketchUp folder, run SU, go to Plugins\ASE exporter
# Note	      : This script is written to export ASE for importing custom scenery into Atari's RollerCoaster Tycoon 3, so there are lots of features missing.
#		           (And other seemingly strange ones present :p)
# Date        	: 05.02.2007
# Type        	: Exporter
# Version     	: 0.4 Wrong UV coordinates fixed, export text as effect point on SketchUp 6
#		  0.3 Feedback on exported meshes and face count.
#		  0.2 Interaction with rct3.rb for effect points
#		  0.1 Initial release
#-----------------------------------------------------------------------------

require 'sketchup.rb'

class SU2ASE

# ---- Settings and global variables ----- #

	def SU2ASE::reset_global_variables
	
		$n_pointlights=0	
		$n_spotlights=0
		$n_cameras=0
		$face=0
		$g_su2ase_scale = 1  # 1 inch = 1 game unit
		$g_su2ase_copy_textures = true
		$g_su2ase_export_constructionpoints = true
		$g_su2ase_model_name=""
		$g_su2ase_textures_prefix = "TX_"
		$g_su2ase_model_textures=[]
		$g_su2ase_count_tri = 0
		$g_su2ase_count_material = 0
		$g_su2ase_faces = []
		$g_su2ase_trans = []
		$g_su2ase_lights = []
	#	$g_su2ase_materials = {}
	#	$g_su2ase_fm_materials = {}
		$g_su2ase_objects = {}
		$g_su2ase_objectnames = []
		$g_su2ase_constructionpoints = []
		$g_su2ase_selected=false
		$g_su2ase_clay=false
		$g_su2ase_exported_meshes ={}
		$animation=false
		$parent_mat=[]
		$fm_comp=[]
		$current_camera=Sketchup.active_model.active_view.camera
	
	end


##### ------  Exporting starts here ------ ######

def SU2ASE::export
	
	SU2ASE.reset_global_variables
	$g_su2ase_selected=true if Sketchup.active_model.selection.length > 0	

	export_selection = %w[Yes No].join("|")
	export_construction = %w[Yes No].join("|")
	if $g_su2ase_selected==true
		dropdowns = [export_selection,export_construction] 
		prompts=["Export selection ONLY   ","Export Construction Points"]
		values=["Yes","Yes"]
		add_item=1
	else
		dropdowns = [export_construction]
		prompts=["Export Construction Points"]
		values=["Yes"]
		add_item=0
	end
	results = inputbox prompts,values, dropdowns, "Export options"
	return nil if not results
	if (add_item==1 &&  results[0]=="Yes") 
		$g_su2ase_selected=true
	else
		$g_su2ase_selected=false
	end
	$g_su2ase_export_constructionpoints = false if results[0+add_item]=="No"


	export_text="Export Model to ASE"
	export_text="Export SELECTION to ASE" if $g_su2ase_selected==true

	model = Sketchup.active_model
	pages = model.pages	
		
	model_filename = File.basename(model.path)
	
	if model_filename!=""
		model_name = model_filename.split(".")[0]
		model_name += ".ase"
	else
		model_name = "Untitled.ase" 	
	end
	
	$g_su2ase_export_file=UI.savepanel(export_text, "" , model_name)

	return if $g_su2ase_export_file==nil		

	if $g_su2ase_export_file==$g_su2ase_export_file.split(".")[0]
		$g_su2ase_export_file+=".ase"
	end
	$g_su2ase_model_name=File.basename($g_su2ase_export_file)
	$g_su2ase_model_name=$g_su2ase_model_name.split(".")[0]

	if $g_su2ase_model_name!=""	
		out = File.new($g_su2ase_export_file,"w") 

		$g_su2ase_path_textures=File.dirname($g_su2ase_export_file)

		start_time=Time.new

		SU2ASE.write_header(out)
		
		SU2ASE.export_mesh(out)
		
		SU2ASE.export_constructionpoints(out)
		
		out.close
				
		end_time=Time.new
		elapsed=end_time-start_time
		time="Model exported in "
			(time=time+"#{(elapsed/3600).floor}h ";elapsed-=(elapsed/3600).floor*3600) if (elapsed/3600).floor>0
			(time=time+"#{(elapsed/60).floor}m ";elapsed-=(elapsed/60).floor*60) if (elapsed/60).floor>0
			time=time+"#{elapsed.round}s. "

		SU2ASE.status_bar(time+" Triangles = #{$g_su2ase_count_tri}")
		export_text="Model saved in file:\n"
		export_text="Selection saved in file:\n" if $g_su2ase_selected==true
		export_text=export_text + $g_su2ase_export_file
		if ($g_su2ase_exported_meshes != {})
			export_text = export_text + "\n\nExported Meshes:\n"
			warn = false
			for me in $g_su2ase_exported_meshes
				export_text = export_text + me[0]
				export_text = export_text + " (#{me[1]} faces)" if me[1]>0
				export_text = export_text + "\n"
				if (me[1]>500)
					warn = true
				end
			end
			if warn
				export_text = export_text + "\nWarning!
At least one of the meshes has more than 500 faces.
You should only create pieces with that many if they are 
likely to be used only once or for the highest detailed 
LOD of a multi-LOD object."
			end
		end
	  	UI.messagebox export_text

		#Materials = #{$g_su2ase_count_material}

	end

	SU2ASE.reset_global_variables

end

# ----------------------------------- About message
def SU2ASE::about
	UI.messagebox("SU2ASE version 0.4. 5th February 2007\nFreeware SketchUp Exporter to 3DS Max ASCII\nAuthor: Belgabor\n\nBased on Su2Kt by Tomasz Marek,\nSu2Pov written by Didier Bur\nand OGRE exporter by Kojack\n
NOTE: This script is written to export ASE for importing custom scenery into Atari's RollerCoaster Tycoon 3, so there are lots of features missing.\n
USAGE:
* Use groups or component instances for \"meshes\" in the RCT3 Importer.
* Component instances have two names, the component name and the instance name. The latter is used.
* You need to map a bitmap texture, basic colours will NOT work.
* Construction points can be used as single vertex meshes for effect points.
* On SketchUp 6 it is also possible to use text for single vertex meshes for effect points." , MB_MULTILINE , "SU2ASE - Model Exporter to ASE") 
end

#### -------------- Export rendering settings ----------------- ##########

def SU2ASE::write_header(out)

	out.puts "*3DSMAX_ASCIIEXPORT	200"
	out.puts "*COMMENT \"AsciiExport Version  2.00 - Exported from SketchUp by su2ase\""
	out.puts "*SCENE {"
	out.puts "	*SCENE_FILENAME \""+$g_su2ase_export_file+"\""
	out.puts "	*SCENE_FIRSTFRAME 1"
	out.puts "	*SCENE_LASTFRAME 250"
	out.puts "	*SCENE_FRAMESPEED 25"
	out.puts "	*SCENE_TICKSPERFRAME 160"
	out.puts "	*SCENE_BACKGROUND_STATIC 0.0566 0.2208 0.4000"
	out.puts "	*SCENE_AMBIENT_STATIC 0.0000 0.0000 0.0000"
	out.puts "}"
	out.puts "*MATERIAL_LIST {"
	out.puts "	*MATERIAL_COUNT 0"
	out.puts "}"

end


#### - Send text to status bar - ####
def SU2ASE::status_bar(stat_text)
	
	statbar = Sketchup.set_status_text stat_text
	
end


def SU2ASE::trunc_path(s)
	j=0
	for i in (0..s.length)
		if s[i,1] == "\\" or s[i,1] == "/"
			j=i
		end 
	end
	if j != 0
	s=s[j+1..s.length]
	end
		if s[s.length-3,3]=="jpg" or s[s.length-3,3]=="JPG" or s[s.length-3,3]=="png" or s[s.length-3,3]=="tif"
		else
		s[s.length-3..s.length]="png"
		end

	s=$g_su2ase_textures_prefix+$g_su2ase_model_name+"\\"+s
	s
end

#### -------- Construction Point export ---------- ######

def SU2ASE::export_constructionpoints(out)
	
	if ($g_su2ase_export_constructionpoints)
		for cp in $g_su2ase_constructionpoints
			cp[0].transform! cp[1]
			if cp[2] == nil
				cpname = "Construction Point <#{"%.4f" %(cp[0].x*$g_su2ase_scale)} #{"%.4f" %(cp[0].y*$g_su2ase_scale)} #{"%.4f" %(cp[0].z*$g_su2ase_scale)}>"
			else
				cpname = cp[2]
			end
			$g_su2ase_exported_meshes [cpname] = 0
out.puts "*GEOMOBJECT {"
out.print "	*NODE_NAME \"#{cpname}\"\n"
out.puts "	*NODE_TM {"
out.print "		*NODE_NAME \"#{cpname}\"\n"
out.puts "		*INHERIT_POS 0 0 0"
out.puts "		*INHERIT_ROT 0 0 0"
out.puts "		*INHERIT_SCL 0 0 0"
out.puts "		*TM_ROW0 1.0000 0.0000 0.0000"
out.puts "		*TM_ROW1 0.0000 1.0000 0.0000"
out.puts "		*TM_ROW2 0.0000 0.0000 1.0000"
out.puts "		*TM_ROW3 1.0000 1.0000 0.0000"
out.puts "		*TM_POS 0.0000 0.0000 0.0000"
out.puts "		*TM_ROTAXIS 1.0000 0.0000 0.0000"
out.puts "		*TM_ROTANGLE 0.0000"
out.puts "		*TM_SCALE 1.0000 1.0000 1.0000"
out.puts "		*TM_SCALEAXIS 1.0000 0.0000 0.0000"
out.puts "		*TM_SCALEAXISANG 0.0000"
out.puts "	}"
out.puts "	*MESH {"
out.puts "		*TIMEVALUE 0"
out.print "		*MESH_NUMVERTEX 1\n"
out.print "		*MESH_NUMFACES 0\n"
out.puts "		*MESH_VERTEX_LIST {"
out.print "			*MESH_VERTEX 0 #{"%.4f" %(cp[0].x*$g_su2ase_scale)} #{"%.4f" %(cp[0].y*$g_su2ase_scale)} #{"%.4f" %(cp[0].z*$g_su2ase_scale)}\n"		
out.puts "		}"
out.puts "		*MESH_FACE_LIST {"
out.puts "		}"
out.puts "		*MESH_NORMALS {"
out.puts "		}"
out.puts "	}"
out.puts "	*PROP_MOTIONBLUR 0"
out.puts "	*PROP_CASTSHADOW 1"
out.puts "	*PROP_RECVSHADOW 1"
out.puts "}"
		end
	end
	#~ SU2ASE.export_fm_faces(export_name)

end

#### -------- Mesh export ---------- ######

def SU2ASE::export_mesh(export_name)
	
	$parent_mat=[]
		
	if $g_su2ase_selected==true
		ents = []
		Sketchup.active_model.selection.each{|e| ents = ents + [e]}
		SU2ASE.export_entities(ents, Geom::Transformation.new, nil)
	else
		SU2ASE.export_entities(Sketchup.active_model.entities, Geom::Transformation.new, nil)
	end

	SU2ASE.export_faces(export_name)
	#~ SU2ASE.export_fm_faces(export_name)

end

###########

def SU2ASE::export_faces(export_name)
	
	for gr in $g_su2ase_objects
		if ($g_su2ase_objects[gr[0]]!=nil and $g_su2ase_objects[gr[0]]!=[])
			SU2ASE.export_face(export_name,gr[0])
			$g_su2ase_objects[gr[0]]=[]
		end
	end
	
end


##### ------------ Exporting entities to an array -------------- ##########

def SU2ASE::export_entities(object, trans, groupname)

if object.class == Sketchup::ComponentInstance
	entity_list=object.definition.entities 
elsif object.class == Sketchup::Group
	entity_list=object.entities 
else
	entity_list=object
end

text=""
text="Component: " + object.definition.name if object.class == Sketchup::ComponentInstance
text="Group" if object.class == Sketchup::Group

SU2ASE.status_bar("Collecting Faces - Level #{$parent_mat.size} - #{text}")  #{$face}

	for e in entity_list
		if (e.class == Sketchup::Group and e.layer.visible?)
			#~ $fm_comp.push(false)

			if e.material != nil
				#mat = e.material
				$parent_mat.push(e.material)
				#SU2ASE.store_textured_entities(e)			
			else
				$parent_mat.push($parent_mat.last)
			end
			
			gr = ""
			if groupname == nil
				gr = e.name
				if gr == ""
					gr = "EmptyGroup"
				end
			else
				gr = groupname
			end

			SU2ASE.export_entities(e, trans*e.transformation, gr)
			
			$parent_mat.pop
			#~ $fm_comp.pop
		end
		if (e.class == Sketchup::ComponentInstance and e.layer.visible?)

			#~ $fm_comp.push(e.definition.behavior.always_face_camera?)

			if e.material != nil
				#mat = e.material
				$parent_mat.push(e.material)
				#SU2ASE.store_textured_entities(e)
			else
				$parent_mat.push($parent_mat.last)
			end
			
			gr = ""
			if groupname == nil
				gr = e.name
				if gr == ""
					gr = "EmptyGroup"
				end
			else
				gr = groupname
			end

			SU2ASE.export_entities(e, trans*e.transformation, gr)
			$parent_mat.pop
			#~ $fm_comp.pop
				
		end
		if (e.class == Sketchup::Face and e.layer.visible?)
			
			gr = ""
			if groupname == nil
				gr = "Ungrouped"
			else
				gr = groupname
			end
			
			if e.material == nil
				mat=$parent_mat.last
			else
				#SU2ASE.store_textured_entities(e)
				mat = e.material
			end
			
			if $g_su2ase_objects[gr] == nil
				$g_su2ase_objects[gr] = []
			end

			$g_su2ase_objects[gr] = $g_su2ase_objects[gr] + [[e,trans,mat]]
			
		end
		if (e.class == Sketchup::ConstructionPoint and e.layer.visible?)
			if not e.get_attribute("ASE", "no_export")
				name = e.get_attribute("ASE", "effect_name")
				$g_su2ase_constructionpoints = $g_su2ase_constructionpoints + [[e.position, trans, name]]
			end
		end
		if (e.class == Sketchup::Text and e.layer.visible? and Sketchup.version_number >= 6000000)
			$g_su2ase_constructionpoints = $g_su2ase_constructionpoints + [[e.point, trans, e.text]]
		end
	end

return nil
end



def SU2ASE::point_to_vector(p)
	Geom::Vector3d.new(p.x,p.y,p.z)
end

##### ---- Exporting polymeshes ---- #######

def SU2ASE::export_face(out,gr)
	meshes = []
	polycount = 0
	pointcount = 0
	mirrored={}
	#~ if fm_mat
		#~ export=$g_su2ase_fm_materials[mat]
	#~ else
		#~ export=$g_su2ase_materials[mat]
	#~ end

	for ft in $g_su2ase_objects[gr]
		polymesh = ft[0].mesh 5 #
		polymesh.transform! ft[1]
		mirrored[polymesh] = true
		xa = SU2ASE.point_to_vector(ft[1].xaxis)
		ya = SU2ASE.point_to_vector(ft[1].yaxis)
		za = SU2ASE.point_to_vector(ft[1].zaxis)
		xy = xa.cross(ya)
		xz = xa.cross(za)
		yz = ya.cross(za)
		if xy.dot(za) < 0
			mirrored[polymesh] = !mirrored[polymesh]
		end
		if xz.dot(ya) < 0
			mirrored[polymesh] = !mirrored[polymesh]
		end
		if yz.dot(xa) < 0
			mirrored[polymesh] = !mirrored[polymesh]
		end
		#pass the material on
		meshes = meshes + [[polymesh,ft[2]]]

		polycount=polycount + polymesh.count_polygons
		pointcount=pointcount + polymesh.count_points
	end

#	has_texture = false
	if gr
		grname = gr
	else
		grname = "Ungrouped2"
	end
	
	$g_su2ase_exported_meshes[grname] = polycount

out.puts "*GEOMOBJECT {"
out.print "	*NODE_NAME \"#{grname}\"\n"
out.puts "	*NODE_TM {"
out.print "		*NODE_NAME \"#{grname}\"\n"
out.puts "		*INHERIT_POS 0 0 0"
out.puts "		*INHERIT_ROT 0 0 0"
out.puts "		*INHERIT_SCL 0 0 0"
out.puts "		*TM_ROW0 1.0000 0.0000 0.0000"
out.puts "		*TM_ROW1 0.0000 1.0000 0.0000"
out.puts "		*TM_ROW2 0.0000 0.0000 1.0000"
out.puts "		*TM_ROW3 1.0000 1.0000 0.0000"
out.puts "		*TM_POS 0.0000 0.0000 0.0000"
out.puts "		*TM_ROTAXIS 1.0000 0.0000 0.0000"
out.puts "		*TM_ROTANGLE 0.0000"
out.puts "		*TM_SCALE 1.0000 1.0000 1.0000"
out.puts "		*TM_SCALEAXIS 1.0000 0.0000 0.0000"
out.puts "		*TM_SCALEAXISANG 0.0000"
out.puts "	}"
out.puts "	*MESH {"
out.puts "		*TIMEVALUE 0"
out.print "		*MESH_NUMVERTEX #{pointcount}\n"
out.print "		*MESH_NUMFACES #{polycount}\n"

#Exporting vertices

SU2ASE.status_bar("Group being exported: " + grname + " - Vertices")

out.puts "		*MESH_VERTEX_LIST {"

	po = 0
	for mesh in meshes
		for p in (1..mesh[0].count_points)
			pos = mesh[0].point_at(p).to_a
			out.print "			*MESH_VERTEX #{po} #{"%.4f" %(pos[0]*$g_su2ase_scale)} #{"%.4f" %(pos[1]*$g_su2ase_scale)} #{"%.4f" %(pos[2]*$g_su2ase_scale)}\n"		
			po = po + 1
		end
	end
out.puts "		}"

#Exporting faces

SU2ASE.status_bar("Group being exported: " + grname + " - Faces")
out.puts "		*MESH_FACE_LIST {"
	
	startindex = 0
	po = 0
	for mesh in meshes
		for poly in mesh[0].polygons
			v1 = (poly[0]>=0?poly[0]:-poly[0])+startindex
			v2 = (poly[1]>=0?poly[1]:-poly[1])+startindex
			v3 = (poly[2]>=0?poly[2]:-poly[2])+startindex
			if !mirrored[mesh[0]]
				out.print "			*MESH_FACE   #{po}: A:     #{v1-1} B:     #{v2-1} C:     #{v3-1} AB: 1 BC: 0 CA: 1 *MESH_SMOOTHING 0 *MESH_MTLID 0\n"
			else
				out.print "			*MESH_FACE   #{po}: A:     #{v2-1} B:     #{v1-1} C:     #{v3-1} AB: 1 BC: 0 CA: 1 *MESH_SMOOTHING 0 *MESH_MTLID 0\n"
			end
			$g_su2ase_count_tri = $g_su2ase_count_tri + 1
			po = po + 1
		end
		startindex = startindex + mesh[0].count_points
	end
	
out.puts "		}"

#Exporting UVs

SU2ASE.status_bar("Group being exported: " + grname + " - UVs")
out.print "		*MESH_NUMTVERTEX #{pointcount}\n"
out.puts "		*MESH_TVERTLIST {"

	po = 0
	for mesh in meshes
		
		for p in (1..mesh[0].count_points)
			#TODO
			#uvq = uvHelper.get_front_UVQ(vert.position)
			#u=uvq.x
			#v=uvq.y
			
			mat = mesh[1]
			
#			if mat.texture and mat==nil
#				texsize = Geom::Point3d.new(mat.texture.width, mat.texture.height, 1)
#			else
				texsize = Geom::Point3d.new(1,1,1)
#			end
			
			uv = [mesh[0].uv_at(p,1).x/texsize.x, mesh[0].uv_at(p,1).y/texsize.y, mesh[0].uv_at(p,1).z/texsize.z]
			
			out.print "			*MESH_TVERT #{po}    #{"%.4f" %(uv[0])}    #{"%.4f" %(uv[1])}    0.0000\n"
			po = po + 1

		end
	end

out.puts "		}"
out.print "		*MESH_NUMTVFACES #{polycount}\n"
out.puts "		*MESH_TFACELIST {"
	
	startindex = 0
	po = 0
	for mesh in meshes
		for poly in mesh[0].polygons
			v1 = (poly[0]>=0?poly[0]:-poly[0])+startindex
			v2 = (poly[1]>=0?poly[1]:-poly[1])+startindex
			v3 = (poly[2]>=0?poly[2]:-poly[2])+startindex
			if !mirrored[mesh[0]]
				out.print "			*MESH_TFACE   #{po}    #{v1-1}    #{v2-1}    #{v3-1}\n"
			else
				out.print "			*MESH_TFACE   #{po}    #{v2-1}    #{v1-1}    #{v3-1}\n"
			end
			po = po + 1
		end
		startindex = startindex + mesh[0].count_points
	end
	
out.puts "		}"

	
#Exporting normals

SU2ASE.status_bar("Group being exported: " + grname + " - Normals")
out.puts "		*MESH_NORMALS {"

	startindex = 0
	po = 0
	for mesh in meshes
		for poly in mesh[0].polygons
			a1 = (poly[0]>=0?poly[0]:-poly[0])
			a2 = (poly[1]>=0?poly[1]:-poly[1])
			a3 = (poly[2]>=0?poly[2]:-poly[2])
			v1 = a1+startindex
			v2 = a2+startindex
			v3 = a3+startindex
			pos1 = mesh[0].point_at(a1).to_a
			pos2 = mesh[0].point_at(a2).to_a
			pos3 = mesh[0].point_at(a3).to_a
			n1 = mesh[0].normal_at(a1).to_a
			n2 = mesh[0].normal_at(a2).to_a
			n3 = mesh[0].normal_at(a3).to_a
			
			pos2[0] = pos2[0] - pos1[0]
			pos2[1] = pos2[1] - pos1[1]
			pos2[2] = pos2[2] - pos1[2]
			pos3[0] = pos3[0] - pos1[0]
			pos3[1] = pos3[1] - pos1[1]
			pos3[2] = pos3[2] - pos1[2]
			
			pos1[0] = (pos2[1]*pos3[2]) - (pos2[2]*pos3[1])
			pos1[1] = (pos2[2]*pos3[0]) - (pos2[0]*pos3[2])
			pos1[2] = (pos2[0]*pos3[1]) - (pos2[1]*pos3[0])
			
			if !mirrored[mesh[0]]
				out.print "			*MESH_FACENORMAL #{po}   #{"%.4f" %(pos1[0])} #{"%.4f" %(pos1[1])} #{"%.4f" %(pos1[2])}\n"
				out.print "				*MESH_VERTEXNORMAL #{v1-1} #{"%.4f" %(n1[0])} #{"%.4f" %(n1[1])} #{"%.4f" %(n1[2])}\n"
				out.print "				*MESH_VERTEXNORMAL #{v2-1} #{"%.4f" %(n2[0])} #{"%.4f" %(n2[1])} #{"%.4f" %(n2[2])}\n"
			else
				out.print "			*MESH_FACENORMAL #{po}   #{"%.4f" %(pos1[1])} #{"%.4f" %(pos1[0])} #{"%.4f" %(pos1[2])}\n"
				out.print "				*MESH_VERTEXNORMAL #{v2-1} #{"%.4f" %(n2[0])} #{"%.4f" %(n2[1])} #{"%.4f" %(n2[2])}\n"
				out.print "				*MESH_VERTEXNORMAL #{v1-1} #{"%.4f" %(n1[0])} #{"%.4f" %(n1[1])} #{"%.4f" %(n1[2])}\n"
			end
			out.print "				*MESH_VERTEXNORMAL #{v3-1} #{"%.4f" %(n3[0])} #{"%.4f" %(n3[1])} #{"%.4f" %(n3[2])}\n"
			po = po + 1
		end
		startindex = startindex + mesh[0].count_points
	end
	
out.puts "		}"

out.puts "	}"
out.puts "	*PROP_MOTIONBLUR 0"
out.puts "	*PROP_CASTSHADOW 1"
out.puts "	*PROP_RECVSHADOW 1"
out.puts "}"

mirrored={}
meshes = []
end



end #Class end

# ---------------------------------------- Menu item
if( not file_loaded?("su2ase4id.rb") )

	main_menu = UI.menu("Plugins").add_submenu("Export ASE to idTech")
	main_menu.add_item("Export") { (SU2ASE.export) }
	main_menu.add_separator
	main_menu.add_item("About SU2ASE") { (SU2ASE.about) }

end
file_loaded("su2ase4id.rb")
